From 3e9e8de312085c5582d7c2b7034e9b7e8ff6d0e7 Mon Sep 17 00:00:00 2001
From: Carl N Baldwin <cnb@plane.localdomain>
Date: Tue, 29 Nov 2005 19:55:39 -0700
Subject: [PATCH] Clean up the usage message.

---
 scripts/restore-script.sh | 30 ++++++++++++++++++++----------
 1 file changed, 20 insertions(+), 10 deletions(-)

diff --git a/scripts/restore-script.sh b/scripts/restore-script.sh
index ed42a96..d961768 100755
--- a/scripts/restore-script.sh
+++ b/scripts/restore-script.sh
@@ -14,16 +14,26 @@ export PATH=${rundir%/}:/bin:/usr/bin:/sbin:/usr/sbin:/sw/bin
 
 if [ ! -z "$1" -o ! -d "$2" ]; then
   err "
-Usage: $0 <source-dir> <relocate-dir> [<mnt-dir>]
-       source-dir   - directory on backup disks to restore from (relative to $mountdir)
-       relocate-dir - base directory to restore files to        (usually /)
-       mnt-dir      - directory where backup disk is mounted    (optional)
-
-  Examples:
-    % $0 / / /mnt/cdrom # Restore everything from disks (explicitly specifying dvd mount point.)
-    % $0 / /            # Restore everything from disks
-    % $0 /home /        # Restore only files under /home on disks to /home on the system
-    % $0 /home /home    # Restore files under /home on disks to /home/home on the system (probably not what you want.)
+
+Usage: $(basename $0) <source-dir> <relocate-dir> [<mnt-dir>]
+  source-dir   - Directory on backup disks to restore (relative to
+                 $mountdir)
+  relocate-dir - Base directory to restore files into (usually /)
+  mnt-dir      - Directory where backup disk is mounted (optional)
+
+Examples:
+  # Restore everything from disks (explicitly specifying dvd mount point.)
+  % $(basename $0) / / /mnt/cdrom
+
+  # Restore everything from disks
+  % $(basename $0) / /
+
+  # Restore only files under /home on disks to /home on the system
+  % $(basename $0) /home /
+
+  # Restore files under /home on disks to /home/home on the system
+  # (this is usually not what you want.)
+  % $(basename $0) /home /home
 "
 fi
 
-- 
2.34.1